${ _("Identifier:") } | ${ report.order.identifier} | ${ _("Invoice number:") } | ${ report.order.invoice_number or '' }
${ _("Branch:") } | ${ report.order.branch.get_description() } | ${ _("Confirm Date:") } | ${ format_date(report.order.confirm_date) }
${ _("Responsible:") } | ${ report.order.responsible.person.name } | ${ _("Removed By:") } | ${ report.order.removed_by.person.name }
${ _("C.F.O.P.:") } | ${ report.order.cfop.get_description() }
${ _("Reason:") } | ${ report.order.reason }